ColumnInfo class

Constructors

ColumnInfo({required String dartName, required String columnName, required String type, required bool isPrimaryKey, required bool autoIncrement})

Properties

autoIncrement bool
final
columnName String
final
dartName String
final
hashCode int
The hash code for this object.
no setterinherited
isPrimaryKey bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited