TableInfo class

Constructors

TableInfo({required Type dartType, required String tableName, required List<ColumnInfo> columns, String? primaryKeyColumn})

Properties

columns List<ColumnInfo>
final
dartType Type
final
hashCode int
The hash code for this object.
no setterinherited
primaryKeyColumn String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tableName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited